# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .cluster import *
from .instance_fleet import *
from .instance_group import *
from .managed_scaling_policy import *
from .security_configuration import *
from ._inputs import *
from . import outputs

def _register_module():
    import pulumi
    from .. import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "aws:emr/cluster:Cluster":
                return Cluster(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:emr/instanceFleet:InstanceFleet":
                return InstanceFleet(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:emr/instanceGroup:InstanceGroup":
                return InstanceGroup(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:emr/managedScalingPolicy:ManagedScalingPolicy":
                return ManagedScalingPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:emr/securityConfiguration:SecurityConfiguration":
                return SecurityConfiguration(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("aws", "emr/cluster", _module_instance)
    pulumi.runtime.register_resource_module("aws", "emr/instanceFleet", _module_instance)
    pulumi.runtime.register_resource_module("aws", "emr/instanceGroup", _module_instance)
    pulumi.runtime.register_resource_module("aws", "emr/managedScalingPolicy", _module_instance)
    pulumi.runtime.register_resource_module("aws", "emr/securityConfiguration", _module_instance)

_register_module()
